Page 34 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 34

Home

    Membership in the Order was based upon a series of
    "degrees" or levels of enlightenment with only the bold
    and ruthless reaching the top and learning the true
    purpose of the Order. Upon joining, members were
    required to take an oath swearing blind obedience to
    their superiors, surrender of their own will, and perpetual
    silence. Through a system of required autobiographies
    and internal spying, the superiors carefully selected those
    suited for advancement to higher degrees.

    Secret police were organized and used to assassinate
    those members who went astray. Their symbol was an

    eye above a pyramid, the same as appears ‘on the back of
    the U.S. one dollar bills.

    My circumstances necessitate, . . . that I should
    remain hidden from most of the members as long as I
    live. I have two immediately below me into whom I
    breathe my whole spirit, and each of these two has again
    two others, and so on. In this way I can set a thousand
    men in motion and on fire in the simplest manner, and in
    this way one must impart orders and operate on politics.*

    The great strength of our Order lies in its
    concealment; let it never appear in any place in its own
    name, but always covered by another name, and another
    occupation.*

    29

    The Illuminati

    As was the case with secret societies, the real leaders

    hid their identity, thus Weishaupt wrote:

    A prime target for the Illuminati was the control of the

    schools, libraries, printing-houses, bookshops, and any